MetaBrainz Code of Conduct
===========================

This project follows the **[MetaBrainz Code of
Conduct](https://metabrainz.org/code-of-conduct "Code of Conduct -
MetaBrainz Foundation")**. The Code of Conduct applies to this and all other
MetaBrainz-sponsored projects.

The full MetaBrainz Code of Conduct is found here:

https://metabrainz.org/code-of-conduct

For questions about the Code of Conduct or to get help, please email
support@metabrainz.org.
